// -*- mode:javascript; indent-tabs-mode:t; js-indent-level:8; -*-
//
//	This program is licensed under the MIT License, which is found at the URL below:
//	https://opensource.org/licenses/MIT
//
//	Copyright (c) 2019, Wei Wang. All rights reserved.

const fs = require('fs');
const readline = require('readline');
const util = require('util');
const tar = require('tar');
const zlib = require('zlib');
const test = require("tap").test;


function get_nsconf (archive, nsconf) {
	return new Promise((resolve, reject) => {
		if (!nsconf) { nsconf = '/nsconfig/ns.conf' }
		console.debug('----> Parsing NetScaler backup: '+archive);
		fs.createReadStream(archive).on('error', console.error)
			.pipe(zlib.createUnzip())
			.pipe(new tar.Parse())
			.on('entry', entry => {
				if (entry.path.endsWith(nsconf)) {
					if ('File' !== entry.type) {
						throw new Error('Wrong type for entry: '+nsconf+' : '+entry.type);
					}
					resolve({tar: archive, entry: entry});
				} else {
					entry.resume();
				}
			})
	});
}

test('NetScaler config read test', t => {
	const archive = './tarball.tar.gz';
	const nsconf = 'tap-tar.js';
	get_nsconf(archive, nsconf).then(nsc => {
		let count = 0;
		// processing nsc as resolved by get_nsconf():
		console.debug('----> Found: '+nsc.entry.path);
		t.ok(nsc.tar == archive);
		t.ok(nsc.entry != undefined);
		readline.createInterface({
			input: nsc.entry
		}).on('line', line => {
			// trim line to save on '^\\s*' & '\\s*$' in regex
			count++
			console.log(line);
			t.ok(null !== line && undefined !== line);
		}).on('close', () => {
			console.log('----> File closed. Line count = '+count);
			t.end();
		});
		console.debug('----> Closing file. Line count = '+count);
	}).catch(err => {
		console.log('Error: ', err, '\n', util.inspect(err.stack));
	});
});
